#include <iostream>
#include <fstream>
#include <vector>
#include <algorithm>

#define lint int64_t

using namespace std;

int best_dists(vector<vector<int>>& dists, int i, int j) {
    int n = dists.size();
    int m = dists[0].size();
    int best = 0;
    if (i > 0) {
        best = dists[i - 1][m - 1];
    }
    if (j > 0) {
        best = max(best, dists[n - 1][j - 1]);
    }

    return best;
}

int best_dists_inv(vector<vector<int>>& dists, int i, int j) {
    int n = dists.size();
    int m = dists[0].size();
    int best = 0;
    if (i < n - 1) {
        best = dists[i + 1][0];
    }
    if (j < m - 1) {
        best = max(best, dists[0][j + 1]);
    }

    return best;
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);

#ifdef _LOCAL
    freopen("../input.txt", "r", stdin);
//    freopen(stdout, 'w', "output.txt");
#endif


    int t = 0;
    cin >> t;

    for (int k = 0; k < t; k++) {
        int n, m;
        cin >> n >> m;
        vector<vector<char>> map(n);
        vector<vector<int>> max_left(n);
        vector<vector<int>> max_up(n);
        vector<vector<int>> max_left_inv(n);
        vector<vector<int>> max_up_inv(n);
        vector<vector<int>> d(n);
        vector<vector<int>> d_inv(n);
        for (int i = 0; i < n; i++) {
            map[i].resize(m);
            max_left[i].resize(m);
            max_up[i].resize(m);
            max_left_inv[i].resize(m);
            max_up_inv[i].resize(m);
            d[i].resize(m);
            d_inv[i].resize(m);
            for (int j = 0; j < m; j++) {
                cin >> map[i][j];
                max_left[i][j] = 0;
                max_up[i][j] = 0;
                d[i][j] = 0;
                max_left_inv[i][j] = 0;
                max_up_inv[i][j] = 0;
                d_inv[i][j] = 0;
            }
        }

        for (int i = 0; i< n; i++) {
            for (int j = 0; j < m; j++) {
                if (map[i][j] == '.') {
                    max_left[i][j] = 1;
                    if (j > 0) {
                        max_left[i][j] += max_left[i][j - 1];
                    }
                    max_up[i][j] = 1;
                    if (i > 0) {
                        max_up[i][j] += max_up[i - 1][j];
                    }
                }

                d[i][j] = max(max_left[i][j], max_up[i][j]);
                if (i > 0) {
                    d[i][j] = max(d[i - 1][j], d[i][j]);
                }
                if (j > 0) {
                    d[i][j] = max(d[i][j - 1], d[i][j]);
                }
            }
        }

        for (int i = n - 1; i > -1; i--) {
            for (int j = m- 1; j > -1; j--) {
                if (map[i][j] == '.') {
                    max_left_inv[i][j] = 1;
                    if (j < m - 1) {
                        max_left_inv[i][j] += max_left_inv[i][j + 1];
                    }
                    max_up_inv[i][j] = 1;
                    if (i < n - 1) {
                        max_up_inv[i][j] += max_up_inv[i + 1][j];
                    }
                }

                d_inv[i][j] = max(max_left_inv[i][j], max_up_inv[i][j]);
                if (i < n - 1) {
                    d_inv[i][j] = max(d_inv[i + 1][j], d_inv[i][j]);
                }
                if (j < m - 1) {
                    d_inv[i][j] = max(d_inv[i][j + 1], d_inv[i][j]);
                }
            }
        }

        int best = 0;

        for (int i = 0; i < n; i++) {
            for (int j = 0; j < m; j++) {
                int hor_len = max_left[i][j];
                int ver_len = max_up[i][j];

                int hor_best = best_dists(d, i, j - hor_len + 1) + hor_len;
                int ver_best = best_dists(d, i - ver_len + 1, j) + ver_len;

                best = max(best, max(hor_best, ver_best));

                hor_len = max_left[i][j];
                ver_len = max_up[i][j];

                hor_best = best_dists_inv(d_inv, i, j) + hor_len;
                ver_best = best_dists_inv(d_inv, i, j) + ver_len;

                best = max(best, max(hor_best, ver_best));
            }
        }

        cout << best << '\n';
    }

    return 0;
}
