#include <iostream>
#include <fstream>
#include <vector>
#include <algorithm>

#define lint int64_t

using namespace std;

typedef int64_t coord;

struct vec2 {
    coord x;
    coord y;

    bool operator==(const vec2 oth) const {
        return x == oth.x && y == oth.y;
    }

    vec2 operator-(const vec2 oth) const {
        return {x - oth.x, y - oth.y};
    }
};

coord cross(const vec2 &a, const vec2 &b) {
    return a.x * b.y - a.y * b.x;
}

bool in_first_half(vec2 v) {
    return v.y > 0 || (v.y == 0 && v.x > 0);
}

bool operator<(const vec2 &a, const vec2 &b) {
    if (in_first_half(a) != in_first_half(b))
        return in_first_half(a) > in_first_half(b);
    return cross(a, b) > 0;
}

struct hash_vec {
    hash<coord> h;

    auto operator()(const vec2 &v) const {
        return h(v.x) * 13 + h(v.y) * 17;
    }
};

bool in_segment(vec2 p, pair<vec2, vec2> seg) {
    vec2 f = p - seg.first;
    vec2 s = seg.second - p;
    if (cross(f, s) != 0) return false;
    return (f.x * s.x + f.y * s.y) > 0;
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);

#ifdef _LOCAL
    freopen("../input2.txt", "r", stdin);
//    freopen(stdout, 'w', "output.txt");
#endif

    int t;
    cin >> t;
    while (t--) {
        int n;
        cin >> n;

        vector<pair<vec2, vec2>> s(n);
        unordered_map<vec2, vector<vec2>, hash_vec> end_segs;

        for (auto &seg: s) {
            cin >> seg.first.x >> seg.first.y >> seg.second.x >> seg.second.y;
            vec2 diff = seg.second - seg.first;
            coord gcd = __gcd(abs(diff.x), abs(diff.y));
            diff.x /= gcd;
            diff.y /= gcd;
            end_segs[seg.first].push_back(diff);
            end_segs[seg.second].push_back(vec2{-diff.x, -diff.y});
        }

        lint ans = 0;

        for (auto &[p, segs]: end_segs) {
            if (segs.size() < 2) continue;

            sort(segs.begin(), segs.end());

            vector<vec2> unique;
            vector<int64_t> counts;

            for (int i = 0; i < segs.size(); i++) {
                if (i == 0 || !(segs[i] == segs[i-1])) {
                    counts.push_back(0);
                    unique.push_back(segs[i]);
                }
                counts.back()++;
            }

            vector<lint> prefsum = {0};
            vector<lint> prefsqsum = {0};
            for (int i = 0; i < counts.size(); i++) {
                prefsum.push_back(prefsum.back() + counts[i]);
                prefsqsum.push_back(prefsqsum.back() + counts[i] * counts[i]);
            }

            for (auto seg: s) {
                if (!in_segment(p, seg)) continue;

                vec2 dir0 = seg.second - seg.first;
                vec2 dir1 = seg.first - seg.second;
                if (dir1 < dir0)
                    swap(dir0, dir1);

                {
                    int L = upper_bound(unique.begin(), unique.end(), dir0) - unique.begin();
                    int R = lower_bound(unique.begin(), unique.end(), dir1) - unique.begin();

                    lint S = prefsum[R] - prefsum[L];
                    lint SS = prefsqsum[R] - prefsqsum[L];
                    ans += S * S - SS;
#ifdef _LOCAL
                    cerr << S << ' ' << SS << endl;
#endif
                }
                {
                    int R = lower_bound(unique.begin(), unique.end(), dir0) - unique.begin();
                    int L = upper_bound(unique.begin(), unique.end(), dir1) - unique.begin();

                    lint S = prefsum[R] + (prefsum.back() - prefsum[L]);
                    lint SS = prefsqsum[R] + (prefsqsum.back() - prefsqsum[L]);
                    ans += S * S - SS;
#ifdef _LOCAL
                    cerr << S << ' ' << SS << endl;
#endif
                }
            }
        }

        cout << ans / 2 << '\n';
//#ifdef _LOCAL
//        return 0;
//#endif
    }

    return 0;
}
